@@ -3,6 +3,10 @@
 #include <filesystem>
 #include <fstream>
 
+#ifdef _WIN32
+#include <cstdlib>
+#endif
+
 #include <curl/curl.h>
 
 #include "libJSONHandle/include/format_handling.h"
@@ -277,7 +281,24 @@ Net::getReply(
     CURL *curl = curl_easy_init();
     if (curl) {
 #ifdef _WIN32
-        curl_easy_setopt(curl, CURLOPT_CAINFO, "curl-ca-bundle.crt");
+        std::filesystem::path programFolderPath(getenv("program_folder_path"));
+        std::filesystem::path curlCertPath = programFolderPath / "curl-ca-bundle.crt";
+
+        std::ifstream curlCertFile(curlCertPath);
+        std::string certLine;
+        std::string certString;
+        while (std::getline(curlCertFile, certLine)) {
+            certString += certLine;
+            certString += '\n';
+        }
+
+        char *certData = certString.data();
+        struct curl_blob blob;
+        blob.data = certData;
+        blob.len = strlen(certData);
+        blob.flags = CURL_BLOB_COPY;
+
+        curl_easy_setopt(curl, CURLOPT_CAINFO_BLOB, &blob);
 #endif
 
         auto [apiUrl, apiHeaders, jsonQuery] = apiParameters;
